;************************************************
; NCL Graphics: 
;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl" 
load "$NCARG_LIB/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin

;************************************************
; set parameter
;************************************************

  cases=(/"Default","Preice","NoPice","Nofhom"/)
  Labels= (/"OBS","Default","Preice","NoPreice","Nofhom"/)

  Ncase = dimsizes(cases)
  print("Ncase"+sprinti("%7.2i",Ncase))
  
  title = "4case"

  Nbin=240-190
  
;************************************************
; read in variables
;************************************************

  bin=new(Nbin,float)
  do i=0,Nbin-1
     bin(i)=i+190.5
  end do

  obs=asciiread("OBS_Ni_kramer.txt",(/Nbin,5/),"float")
  ;print(obs)
  printVarSummary(obs)
  Ymean = new((/Ncase+1,Nbin/), float)
  Y25   = new((/Ncase+1,Nbin/), float)
  Y50   = new((/Ncase+1,Nbin/), float)
  Y75   = new((/Ncase+1,Nbin/), float)
  do i=0,Nbin-1
     Ymean(0,i)  = obs(i,1)*1e3          ; #/cm3 => #/L
     Y25(0,i)    = obs(i,2)*1e3          ; #/cm3 => #/L
     Y50(0,i)    = obs(i,3)*1e3          ; #/cm3 => #/L 
     Y75(0,i)    = obs(i,4)*1e3          ; #/cm3 => #/L
  end do
  

  do v=1,Ncase
     data=asciiread(cases(v-1)+"_Ni_kramer.txt",(/Nbin,5/),"float")
     ;print(data)
     printVarSummary(data)
     do i=0,Nbin-1
        Ymean(v,i)  =data(i,1)              ; #/L   
        Y25(v,i)    =data(i,2)              ; #/L 
        Y50(v,i)    =data(i,3)              ; #/L 
        Y75(v,i)    =data(i,4)              ; #/L 
     end do
     print(cases(v-1))
  end do
  
;************************************************
; set default res
; rea2 for gsn_csm_xy
;************************************************

    wks  = gsn_open_wks ("ps", "Ni_kramer" ) ; open workstation
    gsn_define_colormap(wks,"gui_default")          ; choose colormap
    res2                      = True                ; plot mods desired
    res2@gsnFrame             = False               ; don't advance page
    res2@gsnDraw              = False               ; don't advance frame
    res2@vpXF                  = 0.20     ; x location left
    res2@vpYF                  = 0.80     ; y location  up
    res2@vpWidthF              = 0.60     ; width
    res2@vpHeightF             = 0.35     ; height
    res2@gsnStringFontHeightF  = 0.018
    res2@tiXAxisFontHeightF    = 0.018               ; XAxis String Font
    res2@tiYAxisFontHeightF    = 0.018               ; YAxis String Font
    res2@tmXBLabelFontAspectF  = 1.3
    res2@tmXBLabelFontHeightF  = 0.018   
    res2@tmXBLabelFontThicknessF=1.5    
    res2@tmYLLabelFontAspectF  = 1.3
    res2@tmYLLabelFontHeightF  = 0.018
    res2@tmYLLabelFontThicknessF=1.5
    res2@tiMainString          = "  "     ; title 
    res2@gsnLeftString = "25 50 75 percentile"
    res2@gsnRightString= "30S-75N"
    res2@txFontThicknessF      = 1.0      ; thickness of the lines used to draw the characters
    res2@tiXAxisString = "Temperature (K)"
    res2@tiYAxisString = "Ice Concentration (L~S~-1~N~)"
    res2@tiXAxisFontThicknessF = 1.5
    res2@tiYAxisFontThicknessF = 1.5
    res2@xyYStyle      = "Log"                  ;Log, Linear, Irregular 
    res2@xyComputeXMin = True 
    res2@trYMinF           = 1e0                ; Y axis min 
    res2@trYMaxF           = 1e4                ; Y axis max
    res2@trXMinF           = 190                ; X axis min 
    res2@trXMaxF           = 240                ; X axis max   
    polyres                   = True            ; marker resources
    polyres@gsMarkerIndex     = 1               ; index for circle
    polyres@gsMarkerSizeF     = 0.02            ; size 
    polyres@gsLineDashPattern = 2               ; line patterns
    polyres@gsLineThicknessF  = 1.8             ; line thicknesses
    
  ;************************************************
  ; create plot
  ;************************************************
  
    Y2   =new((/2,Nbin/), float, 1e-8)
    do i=0,Nbin-1
       Y2(0,i)=Y25(0,i)
       Y2(1,i)=Y75(0,i)
    end do
    ltblue = NhlNewColor(wks,0.64,0.71,0.8)     ; add color to colormap
    res2@gsnXYFillColors   = ltblue             ; FillColors
    res2@xyLineColors      = (/ltblue,ltblue/)  ; line colors  
    res2@xyLineThicknesses = (/ 1, 1 /)         ; line thicknesses
    res2@xyDashPatterns    = (/ 0, 0 /)         ; line patterns 
    plot_obs=gsn_csm_xy (wks,bin,Y2,res2)
       
    delete(res2@gsnXYFillColors )
    delete(res2@xyLineColors )
    delete(res2@xyLineThicknesses)
    delete(res2@xyDashPatterns)
    
    res2@xyLineColors      = (/"PaleGreen","red","green4","Brown","RoyalBlue"/)      ; line colors  
    res2@xyLineThicknesses = (/1.0,2.5,2.5,2.5,2.5 /)                       ; line thicknesses
    res2@xyDashPatterns    = (/2  ,0  ,0  ,0  ,0   /)                       ; line patterns
    
    plot = gsn_csm_xy (wks,bin,Y50,res2)
    overlay(plot,plot_obs)
    
    error_bar = new((/Ncase+1,Nbin/),graphic)
    centers   = new((/Ncase+1,Nbin/),graphic)
    do nl=1,Ncase
       polyres@gsMarkerColor     = res2@xyLineColors(nl) ; color of marker
       polyres@gsLineColor       = res2@xyLineColors(nl) ; color of line
       do i=0,Nbin-1
          centers(nl,i)  =gsn_add_polymarker(wks,plot,bin(i),Y50(nl,i),polyres) 
          Ymax=Y75(nl,i)
          Ymin=Y25(nl,i)
          if (Ymax.gt.res2@trYMaxF) then
             Ymax=res2@trYMaxF
          end if
          if (Ymin.lt.res2@trYMinF) then
             Ymin=res2@trYMinF
          end if
          XXX=bin(i)+random_uniform(-0.2,0.2,1)
          ;print(random_uniform(-0.1,0.1,1))
          error_bar(nl,i)=gsn_add_polyline(wks,plot,\
          (/XXX,XXX/), (/Ymax,Ymin/),polyres)
       end do
  end do
  


;************************************************   
; Manually create and attach label
;************************************************

  res_text                    = True                  ; text mods desired
  res_text@txFontHeightF      = 0.02                 ; change text size
  res_text@txFontThicknessF   = 1.8
  res_text@txJust             = "CenterLeft"          ; text justification
  res_lines                   = True                  ; polyline mods desired
  res_lines@gsLineDashPattern = 0.                    ; solid line
  res_lines@gsLineThicknessF  = 5.                    ; line thicker

  xx = (/224 ,228 /)
  yy = (/1.0*exp(0.5),1.0*exp(0.5)/)                              ; yy
  res_lines@gsLineColor       = res2@xyLineColors(4)              ; line color
  dum7 = gsn_add_polyline(wks,plot,xx,yy,res_lines)                ; add polyline
  dum8 = gsn_add_text(wks,plot,Labels(4),xx(1)+1,yy(1),res_text)    ; add text

  xx = (/224 ,228 /)
  yy = (/1.0*exp(1.4),1.0*exp(1.4)/)                              ; yy
  res_lines@gsLineColor       = res2@xyLineColors(3)              ; line color
  dum9 = gsn_add_polyline(wks,plot,xx,yy,res_lines)                ; add polyline
  dum0 = gsn_add_text(wks,plot,Labels(3),xx(1)+1,yy(1),res_text)    ; add text 

  xx = (/210 ,214 /)
  yy = (/1.0*exp(0.5),1.0*exp(0.5)/)                               ; yy
  res_lines@gsLineColor       = res2@xyLineColors(2)              ; line color
  dum5 = gsn_add_polyline(wks,plot,xx,yy,res_lines)                ; add polyline
  dum6 = gsn_add_text(wks,plot,Labels(2),xx(1)+1,yy(1),res_text)    ; add text

  xx = (/210 ,214 /)
  yy = (/1.0*exp(1.4),1.0*exp(1.4)/)                               ; yy
  res_lines@gsLineColor       = res2@xyLineColors(1)              ; line color
  dum3 = gsn_add_polyline(wks,plot,xx,yy,res_lines)                ; add polyline
  dum4 = gsn_add_text(wks,plot,Labels(1),xx(1)+1,yy(1),res_text)    ; add text 

  xx = (/200 ,204 /)
  yy = (/1.0*exp(0.5),1.0*exp(0.5)/)                               ; yy
  delete(res_lines@gsLineColor )
  res_lines@gsLineColor       = ltblue                             ; line color
  res_lines@gsLineThicknessF  = 10.                                ; line thicker
  dum1 = gsn_add_polyline(wks,plot,xx,yy,res_lines)                ; add polyline
  dum2 = gsn_add_text(wks,plot,Labels(0),xx(1)+1,yy(1),res_text); add text
   
  draw(plot)
  frame(wks)
   
end


;************************************************
;res2@xyLineColors      = (/"black","red"/) 
;/"red","Brown","green4","RoyalBlue","black"/)
; "PaleGreen","Brown","black","red","RoyalBlue","green4"
;"white","black","RoyalBlue","LightSkyBlue","gray75","gray25" 
;"PowderBlue","lightseagreen","PaleGreen","Wheat","Brown","Pink"
;The line style is changed using an integer from 0 to 16.
;The default is line index 0 (solid). 
;ltpink = NhlNewColor(wks,1.0,0.71,0.76)  ; add color to colormap
;ltblue = NhlNewColor(wks,0.64,0.71,0.8)  ; 
