;************************************************
; NCL Graphics: 
;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl" 
load "$NCARG_LIB/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin

;************************************************
; set parameter
;************************************************

  Ncase = 4
  case  = (/"Default","Preice","PreiceBN","PreiceKL"/)
  label = (/"Default","Preice","PreiceBN","PreiceKL"/)
  print("Ncase"+case)
  
  vname  = "AWNIi"
  vunits = "L~S~-1~N~" 
  vscale = 1e-3
  
  title  = "AWNI_PDPI"
    
;************************************************
; Open netCDF file and read in dimensions
;************************************************

   dir="/glade/u/home/xshi/plot4paper/preexisting_ice/data_annualmean/"
   filename=dir+"IN_"+case(1)+".nc"
   fi=addfile(filename,"r")
   lev   = fi->lev
   lat   = fi->lat
   lon   = fi->lon 
   nlev  = dimsizes(lev)                           
   nlat  = dimsizes(lat)
   nlon  = dimsizes(lon)
   print("nlev "+sprinti("%7.2i",nlev))
   print("nlat "+sprinti("%7.2i",nlat))
   print("nlon "+sprinti("%7.2i",nlon))
 
   P0mb =1000.
   hyam = fi->hyam
   hybm = fi->hybm
   pnew = (/ 100., 121., 143.,       \   ; mb
             168., 200., 233., 274., \ 
             300., 379., 446., 500., \ 
             610., 700., 763., 821., \ 
             850., 887., 913., 936., \ 
             957., 976., 993., 1000. /) 
   nlev_p  = dimsizes(pnew)
   print("nlev_p "+sprinti("%7.2i",nlev_p))

   ; type of interpolation: 1 = linear, 2 = log, 3 = loglog
   interp = 2
   ; is extrapolation desired if data is outside the range of PS
   extrap = False
 
   
;************************************************
; set default res
; res1 for gsn_csm_contour
; resp for gsn_panel
;************************************************
  wks   = gsn_open_wks ("ps", title )             ; open workstation
  gsn_define_colormap(wks,"gui_default")          ; choose colormap
  ;gsn_define_colormap(wks,"wh-bl-gr-ye-re")          ; choose colormap
  res1                      = True                ; plot mods desired
  res1@gsnFrame             = False               ; advance page
  res1@gsnDraw              = False                
  res1@gsnSpreadColors      = True                 ; use full colormap 
  ;res1@gsnSpreadColorStart  = -40
  ;res1@gsnSpreadColorEnd    = 40
  res1@cnFillOn             = True                 ; turn on color
  res1@cnLinesOn            = False                ; turn on/off contour lines
  res1@cnFillMode           = "AreaFill"           ; default "AreaFill" "RasterFill"
  res1@lbLabelBarOn          = True                ; turn on/off the labelbar
  res1@lbLabelsOn            = True                ; turn on/off the label of labelbar
  res1@lbOrientation         = "Vertical"          ; labelbar Orientation "Vertical"
  res1@lbBoxMinorExtentF     = 0.30                ; wide of the LabelBar 
  res1@lbLabelFontHeightF    = 0.025                                               
  res1@lbLabelAutoStride     = False                ; optimal labels         
  res1@cnLineLabelsOn        = False                 ; turn on line labels
  res1@cnLinesOn             = False               ; turn on line 
  res1@cnLevelSelectionMode = "ExplicitLevels"      ; "ManualLevels""ExplicitLevels"
  res1@cnLevelFlags         = False
  res1@vpXF                  = 0.10     ; x location left
  res1@vpYF                  = 0.80     ; y location  up
  res1@vpWidthF              = 0.60     ; width
  res1@vpHeightF             = 0.35     ; height
  res1@tiMainString          = " "      ; title    
  res1@tiMainFontThicknessF  = 0.40
  res1@tiMainFontHeightF     = 0.025
  res1@gsnStringFontHeightF  = 0.025       
  res1@tiXAxisFontHeightF    = 0.025               ; XAxis String Font
  res1@tiYAxisFontHeightF    = 0.025              ; YAxis String Font
  res1@tmXBLabelFontAspectF  = 1.3
  res1@tmXBLabelFontHeightF  = 0.025       
  res1@tmYLLabelFontAspectF  = 1.3
  res1@tmYLLabelFontHeightF  = 0.025
  res1@trYReverse            = True
  res1@gsnYAxisIrregular2Linear = True
  res1@tmYRMode                = "Automatic"  ; no right axis label
  resP                 = True          
  resP@gsnPanelYWhiteSpacePercent = 0  ; draw panel with white space added
  resP@gsnPanelXWhiteSpacePercent = 0  ; draw panel with white space added
  resP@txString            = title
 
;************************************************
; read in variables & create plot
;************************************************

  plot = new(Ncase,graphic)
  
  do i=0,Ncase-1
     dir="/glade/u/home/xshi/plot4paper/preexisting_ice/data_annualmean/"
     filename=dir+"IN_"+case(i)+".nc"
     fi=addfile(filename,"r")
     print(" read "+case(i))
     PS   = fi->PS    ; pa
     INfretemp=fi->INFreIN(lev|:, lat|:, lon|:)
     INfreh = vinth2p(INfretemp,hyam,hybm,pnew,PS,interp,P0mb,1,extrap)
     FREQItemp=fi->FREQIi(lev|:, lat|:, lon|:)
     FREQIh = vinth2p(FREQItemp,hyam,hybm,pnew,PS,interp,P0mb,1,extrap)
     Vartemp=fi->$vname$(lev|:, lat|:, lon|:)
     Varh = vinth2p(Vartemp,hyam,hybm,pnew,PS,interp,P0mb,1,extrap)
     Varh&lev_p@units = "hPa"
     VarLevLat = dim_avg_Wrap(Varh(lev_p|:, lat|:, lon|:)) 
     VarLevLat@_FillValue = -9999.99
     ;printVarSummary(VarLevLat)
     do nz=0,nlev_p-1
     do ny=0,nlat-1
        VarLevLat(nz,ny)=0.
        count=0
        do nx=0,nlon-1
           if (.not.ismissing(INfreh(nz,ny,nx)).and..not.ismissing(FREQIh(nz,ny,nx))) then
           if (.not.ismissing(Varh(nz,ny,nx))) then
           if ((INfreh(nz,ny,nx).ge.0.001).and.(FREQIh(nz,ny,nx).ge.0.001)) then  
              Varh(nz,ny,nx)=Varh(nz,ny,nx)/FREQIh(nz,ny,nx)
              VarLevLat(nz,ny)=VarLevLat(nz,ny)+Varh(nz,ny,nx)
              count=count+1
           end if
           end if
           end if
        end do
        if (count.ge.1) then  
           VarLevLat(nz,ny)=VarLevLat(nz,ny)*vscale/count    
        else
           VarLevLat(nz,ny)= -9999.99
        end if
     end do 
     end do
     delete(INfreh)
     delete(FREQIh)

     dir="/glade/u/home/xshi/plot4paper/preexisting_ice/data_annualmean/"
     filename=dir+"IN_"+case(i)+"PI.nc"
     fi=addfile(filename,"r")
     print(" read "+case(i))
     PS   = fi->PS    ; pa
     INfretemp=fi->INFreIN(lev|:, lat|:, lon|:)
     INfreh = vinth2p(INfretemp,hyam,hybm,pnew,PS,interp,P0mb,1,extrap)
     FREQItemp=fi->FREQIi(lev|:, lat|:, lon|:)
     FREQIh = vinth2p(FREQItemp,hyam,hybm,pnew,PS,interp,P0mb,1,extrap)
     Vartemp=fi->$vname$(lev|:, lat|:, lon|:)
     Varh = vinth2p(Vartemp,hyam,hybm,pnew,PS,interp,P0mb,1,extrap)
     Varh&lev_p@units = "hPa"
     VarLevLatPI = dim_avg_Wrap(Varh(lev_p|:, lat|:, lon|:)) 
     VarLevLatPI@_FillValue = -9999.99
     ;printVarSummary(VarLevLatPI)
     do nz=0,nlev_p-1
     do ny=0,nlat-1
        VarLevLatPI(nz,ny)=0.
        count=0
        do nx=0,nlon-1
           if (.not.ismissing(INfreh(nz,ny,nx)).and..not.ismissing(FREQIh(nz,ny,nx))) then
           if (.not.ismissing(Varh(nz,ny,nx))) then
           if ((INfreh(nz,ny,nx).ge.0.001).and.(FREQIh(nz,ny,nx).ge.0.001)) then  
              Varh(nz,ny,nx)=Varh(nz,ny,nx)/FREQIh(nz,ny,nx)
              VarLevLatPI(nz,ny)=VarLevLatPI(nz,ny)+Varh(nz,ny,nx)
              count=count+1
           end if
           end if
           end if
        end do
        if (count.ge.1) then  
           VarLevLatPI(nz,ny)=VarLevLatPI(nz,ny)*vscale/count    
        else
           VarLevLatPI(nz,ny)= -9999.99
        end if
     end do 
     end do
     delete(INfreh)
     delete(FREQIh)

     do nz=0,nlev_p-1
     do ny=0,nlat-1
        if (.not.ismissing(VarLevLat(nz,ny)).and..not.ismissing(VarLevLatPI(nz,ny))) then
           VarLevLat(nz,ny)=VarLevLat(nz,ny)-VarLevLatPI(nz,ny) 
        else
           VarLevLat(nz,ny)= -9999.99
        end if
     end do 
     end do

     res1@gsnLeftString = label(i)
     res1@gsnRightString= vunits  
     res1@cnLevels             = (/-20,-10,0,10,20,40,60/)
     if ((i.eq.0).or.(i.eq.2).or.(i.eq.4)) then
        res1@tiYAxisString = "Pressure(hpa)"  
     else       
        res1@tiYAxisString = " "
     end if
     if ((i.eq.2).or.(i.eq.3)) then
        res1@tiXAxisString         = "Latitude"
     else       
        res1@tiXAxisString         = " "
     end if  
            
     plot(i) = gsn_csm_pres_hgt(wks,VarLevLat(:,:), res1) 

     delete(VarLevLat)
     delete(VarLevLatPI)

  end do 
  
  gsn_panel(wks,plot,(/Ncase/2,2/),resP)
  
end



