;************************************************
; NCL Graphics: 
;************************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl" 
load "$NCARG_LIB/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin

;************************************************
; set parameter
; Drawing superscripts/subscripts in a text 
; ~S~TEXT~N~   ~B~TEXT~N~
;************************************************

  Ncase=4
  labels= (/"Default","Preice","PreiceBN","PreiceKL"/)
  cases = (/"Default","Preice","PreiceBN","PreiceKL"/)

  Nyears=5
  years = (/"01","02","03","04","05"/)
  
  title  = "AIE"

  Nbin=32
  
  Nvar = 4
  var2dLat = (/ \
\;Format (name --- units ----- scale-----min-----max) )  
   (/"LWCF"   , "W m~S~-2~N~" , "1.0"  ,   "-5"  ,   "3"  /),\
   (/"SWCF"   , "W m~S~-2~N~" , "1.0"  ,"-5"  ,    "3"  /),\
   (/"CDNUMI" , "10~S~6~N~ m~S~-2~N~","1e-6"  ,   "-20"  ,    "40"  /),\
   (/"TGCLDIWP","g m~S~-2~N~" , "1e3"  ,   "-3"  ,   "3"  /),\
   ;(/"CF"     , "W m~S~-2~N~" , "1.0"  , "-5"  ,   "5"  /),\
   (/"x"      , "x"           , "1e6"  ,   "x"  ,   "x"   /) \
/)
    
;************************************************
; Open netCDF file and read in dimensions
;************************************************

   dir="/glade/u/home/xshi/plot4paper/preexisting_ice/data_annualmean/"
   filename=dir+"IN_"+cases(0)+".nc"
   fi=addfile(filename,"r")
   lev   = fi->lev
   lat   = fi->lat
   lon   = fi->lon 
   nlev  = dimsizes(lev)                           
   nlat  = dimsizes(lat)
   nlon  = dimsizes(lon)
   print("nlev "+sprinti("%7.2i",nlev))
   print("nlat "+sprinti("%7.2i",nlat))
   print("nlon "+sprinti("%7.2i",nlon))

 
;************************************************
; set default res
; res1 for gsn_csm_contour
; resp for gsn_panel
;************************************************
  wks   = gsn_open_wks ("ps", title+"4casePD-PI" )             ; open workstation
  gsn_define_colormap(wks,"gui_default")          ; choose colormap
  res2                      = True                ; plot mods desired
  res2@gsnFrame             = False               ; advance page
  res2@gsnDraw              = False                
  res2@vpXF                  = 0.20     ; x location left
  res2@vpYF                  = 0.70     ; y location  up
  res2@vpWidthF              = 0.65     ; width
  res2@vpHeightF             = 0.30     ; height
  res2@gsnStringFontHeightF  = 0.022
  res2@tiXAxisFontHeightF    = 0.022               ; XAxis String Font
  res2@tiYAxisFontHeightF    = 0.022               ; YAxis String Font
  res2@tmXBLabelFontAspectF  = 1.3
  res2@tmXBLabelFontHeightF  = 0.022       
  res2@tmYLLabelFontAspectF  = 1.3
  res2@tmYLLabelFontHeightF  = 0.022
  res2@tiMainString          = " "       
  res2@xyLineColors      = (/"red","green4","Brown","RoyalBlue","black"/)  ; line colors  
  res2@xyLineThicknesses = (/3  ,3  ,3  ,3  ,1  /)        ; line thicknesses
  res2@xyDashPatterns    = (/1  ,1  ,1  ,1  ,2  /)        ; line patterns
  res_text                    = True                  ; text mods desired
  res_text@txFontHeightF      = 0.025                 ; change text size
  res_text@txFontThicknessF   = 1.5             
  res_text@txJust             = "CenterLeft"          ; text justification
  polyres                   = True            ; marker resources
  polyres@gsMarkerIndex     = 1               ; index for circle
  polyres@gsMarkerSizeF     = 0.02            ; size 
  polyres@gsLineDashPattern = 0               ; line patterns
  polyres@gsLineThicknessF  = 1.0             ; line thicknesses
  resP                     = True          
  resP@gsnPanelYWhiteSpacePercent = 0  ; draw panel with white space added
  resP@gsnPanelXWhiteSpacePercent = 2  ; draw panel with white space added
  resP@txString            = title 
  
;************************************************
; read in variables & create plot
;************************************************

  ilev = (/2.25523952394724, 5.03169186413288, 10.1579474285245,\
           18.5553170740604, 30.6691229343414, 45.8674766123295, 63.3234828710556,\
           80.7014182209969, 94.9410423636436, 111.693210899830, 131.401270627975,\
           154.586806893349, 181.863352656364, 213.952820748091, 251.704417169094,\
           296.117216348648, 348.366588354111, 409.835219383240, 482.149928808212,\
           567.224420607090, 652.332969009876, 730.445891618729, 796.363070607185,\
           845.353666692972, 873.715866357088, 900.324631482363, 924.964462406933,\
           947.432334534824, 967.538624536246, 985.112190246582, 1000. /)
  dlev = new((/nlev/), float) ; "NO_FillValue" -999
  pdel = new((/nlev,nlat,nlon/), float)
  gravit = 9.8
  
  
  plot = new(Nvar,graphic)

  error_bar = new((/Nvar,Ncase,Nbin/),graphic)
  
  do iv=0,Nvar-1
     vname  =  var2dLat(iv,0)
     if (vname.eq."x") then 
        continue
     end if
     vunits = var2dLat(iv,1)
     vscale = stringtofloat(var2dLat(iv,2))
     varmin = stringtofloat(var2dLat(iv,3))
     varmax = stringtofloat(var2dLat(iv,4))
     print(vname+" "+vunits+" "+sprintf("%12.10f",vscale) )
     res2@gsnLeftString = vname
     if (vname.eq."TGCLDIWP") then 
        res2@gsnLeftString = "IWP"
     end if
     res2@tiYAxisString = " "
     res2@gsnRightString= vunits
     res2@trYMinF       = varmin             ; Y axis min 
     res2@trYMaxF       = varmax             ; Y axis max 
     if ((iv.eq.3).or.(iv.eq.2)) then
        res2@tiXAxisString = "Latitude"
     else
        res2@tiXAxisString = " "
     end if
     Varplot = new((/Ncase+1,nlat/), float)
     Varplot(:,:)=-999.
     Varplot(Ncase,:)=0. 
     VarplotDev = new((/Ncase,nlat/), float) 
     VarplotPI = new((/Ncase,nlat/), float)
     VarplotPI(:,:)=-999. 
     Varplot5yr = new((/Nyears,Ncase,nlat/), float)
     Varplot5yr(:,:,:)=-999. 
     VarplotPI5yr = new((/Nyears,Ncase,nlat/), float)
     VarplotPI5yr(:,:,:)=-999. 
     do i=0,Ncase-1
        filename=dir+"IN_"+cases(i)+".nc"
        fi=addfile(filename,"r")
        ;print(" open  "+filename)
        if ((vname.eq."SWCF").or.(vname.eq."LWCF").or.(vname.eq."TGCLDIWP")) then 
           VarLattemp = dim_avg_Wrap(fi->$vname$(lat|:, lon|:))
           VarLattemp = VarLattemp*vscale
        end if
        if (vname.eq."CF") then 
           VarLattemp1= dim_avg_Wrap(fi->SWCF(lat|:, lon|:))
           VarLattemp2= dim_avg_Wrap(fi->LWCF(lat|:, lon|:))
           VarLattemp = VarLattemp1+VarLattemp2
           VarLattemp = VarLattemp*vscale
           delete(VarLattemp1)
           delete(VarLattemp2)
        end if
        if (vname.eq."CDNUMI") then
            PS = fi->PS(lat|:, lon|:)
            do nz=0,nlev-1
               dlev(nz)=(ilev(nz+1)-ilev(nz))/1000.
               do nx=0,nlon-1
               do ny=0,nlat-1
                  pdel(nz,ny,nx)=dlev(nz)*PS(ny,nx)
               end do
               end do
           end do
           NUMICE = fi->NUMICE(lev|:, lat|:, lon|:) ; #/kg
           NUMICE = NUMICE * pdel / gravit          ; #/m2
           CDNUMI = new((/nlat,nlon/), float)
           CDNUMI = dim_sum_Wrap(NUMICE(lat |:, lon |:, lev |0:29))
           CDNUMI = CDNUMI*vscale
           VarLattemp=dim_avg(CDNUMI(lat|:,lon|:))
        end if
        Varplot(i,:)=VarLattemp(:)
        delete(VarLattemp)
        do yr=0,Nyears-1
           filename=dir+"IN_"+cases(i)+years(yr)+".nc"
           fi=addfile(filename,"r")
           ;print(" open  "+filename)
           if ((vname.eq."SWCF").or.(vname.eq."LWCF").or.(vname.eq."TGCLDIWP")) then 
              VarLattemp = dim_avg_Wrap(fi->$vname$(lat|:, lon|:))
              VarLattemp = VarLattemp*vscale
           end if
           if (vname.eq."CF") then 
              VarLattemp1= dim_avg_Wrap(fi->SWCF(lat|:, lon|:))
              VarLattemp2= dim_avg_Wrap(fi->LWCF(lat|:, lon|:))
              VarLattemp = VarLattemp1+VarLattemp2
              VarLattemp = VarLattemp*vscale
              delete(VarLattemp1)
              delete(VarLattemp2)
           end if
           if (vname.eq."CDNUMI") then
              PS = fi->PS(lat|:, lon|:)
              do nz=0,nlev-1
                 dlev(nz)=(ilev(nz+1)-ilev(nz))/1000.
                 do nx=0,nlon-1
                 do ny=0,nlat-1
                    pdel(nz,ny,nx)=dlev(nz)*PS(ny,nx)
                 end do
                 end do
              end do
              NUMICE = fi->NUMICE(lev|:, lat|:, lon|:) ; #/kg
              NUMICE = NUMICE * pdel / gravit          ; #/m2
              CDNUMI = dim_sum_Wrap(NUMICE(lat |:, lon |:, lev |0:29))
              CDNUMI = CDNUMI*vscale
              VarLattemp=dim_avg(CDNUMI(lat|:,lon|:))
           end if
           Varplot5yr(yr,i,:)=VarLattemp(:)
           delete(VarLattemp)
        end do
        filename=dir+"IN_"+cases(i)+"PI.nc"
        fi=addfile(filename,"r")
        ;print(" open  "+filename)
        if ((vname.eq."SWCF").or.(vname.eq."LWCF").or.(vname.eq."TGCLDIWP")) then 
           VarLattemp = dim_avg_Wrap(fi->$vname$(lat|:, lon|:))
           VarLattemp = VarLattemp*vscale
        end if
        if (vname.eq."CF") then 
           VarLattemp1= dim_avg_Wrap(fi->SWCF(lat|:, lon|:))
           VarLattemp2= dim_avg_Wrap(fi->LWCF(lat|:, lon|:))
           VarLattemp = VarLattemp1+VarLattemp2
           VarLattemp = VarLattemp*vscale
           delete(VarLattemp1)
           delete(VarLattemp2)
        end if
        if (vname.eq."CDNUMI") then
            PS = fi->PS(lat|:, lon|:)
            do nz=0,nlev-1
               dlev(nz)=(ilev(nz+1)-ilev(nz))/1000.
               do nx=0,nlon-1
               do ny=0,nlat-1
                  pdel(nz,ny,nx)=dlev(nz)*PS(ny,nx)
               end do
               end do
           end do
           NUMICE = fi->NUMICE(lev|:, lat|:, lon|:) ; #/kg
           NUMICE = NUMICE * pdel / gravit          ; #/m2
           CDNUMI = dim_sum_Wrap(NUMICE(lat |:, lon |:, lev |0:29))
           CDNUMI = CDNUMI*vscale
           VarLattemp=dim_avg(CDNUMI(lat|:,lon|:))
        end if
        VarplotPI(i,:)=VarLattemp(:)
        delete(VarLattemp)
        Varplot(i,:)=Varplot(i,:)-VarplotPI(i,:)
        do yr=0,Nyears-1
           filename=dir+"IN_"+cases(i)+"PI"+years(yr)+".nc"
           fi=addfile(filename,"r")
           ;print(" open  "+filename)
           if ((vname.eq."SWCF").or.(vname.eq."LWCF").or.(vname.eq."TGCLDIWP")) then 
              VarLattemp = dim_avg_Wrap(fi->$vname$(lat|:, lon|:))
              VarLattemp = VarLattemp*vscale
           end if
           if (vname.eq."CF") then 
              VarLattemp1= dim_avg_Wrap(fi->SWCF(lat|:, lon|:))
              VarLattemp2= dim_avg_Wrap(fi->LWCF(lat|:, lon|:))
              VarLattemp = VarLattemp1+VarLattemp2
              VarLattemp = VarLattemp*vscale
              delete(VarLattemp1)
              delete(VarLattemp2)
           end if
           if (vname.eq."CDNUMI") then
              PS = fi->PS(lat|:, lon|:)
              do nz=0,nlev-1
                 dlev(nz)=(ilev(nz+1)-ilev(nz))/1000.
                 do nx=0,nlon-1
                 do ny=0,nlat-1
                    pdel(nz,ny,nx)=dlev(nz)*PS(ny,nx)
                 end do
                 end do
              end do
              NUMICE = fi->NUMICE(lev|:, lat|:, lon|:) ; #/kg
              NUMICE = NUMICE * pdel / gravit          ; #/m2
              CDNUMI = new((/nlat,nlon/), float)
              CDNUMI = dim_sum_Wrap(NUMICE(lat |:, lon |:, lev |0:29))
              CDNUMI = CDNUMI*vscale
              VarLattemp=dim_avg(CDNUMI(lat|:,lon|:))
           end if
           VarplotPI5yr(yr,i,:)=VarLattemp(:)
           delete(VarLattemp)
           Varplot5yr(yr,i,:)=Varplot5yr(yr,i,:)-VarplotPI5yr(yr,i,:)         
        end do
        do ny=0,nlat-1
           VarplotDev(i,ny)=0.
           do yr=0,Nyears-1
              Temp=Varplot5yr(yr,i,ny)-Varplot(i,ny)
              Temp=Temp*Temp
              VarplotDev(i,ny)=VarplotDev(i,ny)+Temp
           end do  
           VarplotDev(i,ny)=sqrt(VarplotDev(i,ny)/Nyears) 
        end do
     end do

     plot(iv) = gsn_csm_xy (wks,lat,Varplot(:,:),res2)
     ;plot(iv) = gsn_csm_xy (wks,lat,Varplot5yr(2,:,:),res2)
     ;plot(iv) = gsn_csm_xy (wks,lat,VarplotDev(:,:),res2)

     do i=0,Ncase-1
        polyres@gsLineColor       =  res2@xyLineColors(i) ; color of line
        do j=0,Nbin-1
           nn=j*6+i+1
           XXX=lat(nn)
           Ymax=Varplot(i,nn)+VarplotDev(i,nn)
           Ymin=Varplot(i,nn)-VarplotDev(i,nn)
           ;print(sprintf("%12.0f",i)+sprintf("%12.0f",j)+sprintf("%12.0f",nn))
           ;print(sprintf("%12.1f",XXX)+sprintf("%12.2f",Ymax)+sprintf("%12.2f",Ymin))
           error_bar(iv,i,j)=gsn_add_polyline(wks,plot(iv),\
          (/XXX,XXX/), (/Ymax,Ymin/),polyres)
        end do
     end do
     

     if (vname.eq."LWCF") then 
        xx=-5
        yy=-2.5
        i=0
        res_text@txFontColor  = res2@xyLineColors(i)
        test_add = gsn_add_text(wks,plot(iv),labels(i),xx,yy,res_text)
        xx=45
        yy=-2.5
        i=1
        res_text@txFontColor  = res2@xyLineColors(i)
        test_add = gsn_add_text(wks,plot(iv),labels(i),xx,yy,res_text)
        xx=-5
        yy=-4.0
        i=2
        res_text@txFontColor  = res2@xyLineColors(i)
        test_add = gsn_add_text(wks,plot(iv),labels(i),xx,yy,res_text)
        xx=45
        yy=-4.0
        i=3
        res_text@txFontColor  = res2@xyLineColors(i)
        test_add = gsn_add_text(wks,plot(iv),labels(i),xx,yy,res_text)
     end if
     delete(Varplot)
     delete(VarplotPI)

  end do
  
  gsn_panel(wks,plot,(/Nvar/2,2/),resP)
  
  print("output .ps file : "+title)
  
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;res2@xyLineColors      = (/"black","red"/)
;(/"red","RoyalBlue","black", "LimeGreen", "DarkSalmon"/)  ; line colors
;"PaleGreen","Brown","RoyalBlue","red","LimeGreen", "DarkSalmon"
;"white","black","RoyalBlue","LightSkyBlue","gray75","gray25" , "Coral"
;"PowderBlue","lightseagreen","PaleGreen","Wheat","Brown","Pink"
;"CadetBlue", "Ivory", "LimeGreen", "DarkSalmon","Coral",
;"LightSalmon","OliveDrab","AliceBlue","Purple",
;"Coral""transparent","transparent"

